pub struct Containers<'a> { /* private fields */ }Expand description
Interface for docker containers
Implementations
Sourceimpl<'a> Containers<'a>
impl<'a> Containers<'a>
Sourcepub fn new(docker: &'a Docker) -> Containers<'a>
pub fn new(docker: &'a Docker) -> Containers<'a>
Exports an interface for interacting with docker containers
Sourcepub fn list(
&self,
opts: &ContainerListOptions,
) -> impl Future<Item = Vec<ContainerRep>, Error = Error>
pub fn list( &self, opts: &ContainerListOptions, ) -> impl Future<Item = Vec<ContainerRep>, Error = Error>
Lists the container instances on the docker host
Sourcepub fn get<'b>(&self, name: &'b str) -> Container<'a, 'b>
pub fn get<'b>(&self, name: &'b str) -> Container<'a, 'b>
Returns a reference to a set of operations available to a specific container instance
Sourcepub fn create(
&self,
opts: &ContainerOptions,
) -> impl Future<Item = ContainerCreateInfo, Error = Error>
pub fn create( &self, opts: &ContainerOptions, ) -> impl Future<Item = ContainerCreateInfo, Error = Error>
Returns a builder interface for creating a new container instance